*******
Credits
*******

Development Leads
=================

* John Dewey <john@dewey.ws>

Core Committers
===============

* Abel Lopez <abelopez@cisco.com>
* Adam Brown <adambr2@cisco.com>
* Duncan Hutty <dhutty@cisco.com>
* Erik Nadel <einadel@wpi.edu>
* Rémy Greinhofer <regreinh@cisco.com>
* Matthew Montgomery <matthew@signed8bit.com>

Contributors
============

.. code-block:: bash

  $ git shortlog -s | cut -c8-
